@@ -13,20 +13,27 @@ typedef Eo Elm_Genlist_Pan;
 
 
 #endif
+/** Elementary genlist pan class
+ *
+ * @ingroup Elm_Genlist_Pan
+ */
 #define ELM_GENLIST_PAN_CLASS elm_genlist_pan_class_get()
 
-EWAPI const Eo_Class *elm_genlist_pan_class_get(void);
+EWAPI const Efl_Class *elm_genlist_pan_class_get(void);
 
-EOAPI extern const Eo_Event_Description _ELM_GENLIST_PAN_EVENT_ITEM_FOCUSED;
-EOAPI extern const Eo_Event_Description _ELM_GENLIST_PAN_EVENT_ITEM_UNFOCUSED;
+EWAPI extern const Efl_Event_Description _ELM_GENLIST_PAN_EVENT_ITEM_FOCUSED;
 
-/**
- * No description
+/** Called when item got focus
+ *
+ * @ingroup Elm_Genlist_Pan
  */
 #define ELM_GENLIST_PAN_EVENT_ITEM_FOCUSED (&(_ELM_GENLIST_PAN_EVENT_ITEM_FOCUSED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_GENLIST_PAN_EVENT_ITEM_UNFOCUSED;
+
+/** Called when item lost focus
+ *
+ * @ingroup Elm_Genlist_Pan
  */
 #define ELM_GENLIST_PAN_EVENT_ITEM_UNFOCUSED (&(_ELM_GENLIST_PAN_EVENT_ITEM_UNFOCUSED))
 
