@@ -13,9 +13,13 @@ typedef Eo Evas_Canvas3D_Texture;
 
 
 #endif
+/** Evas 3d canvas texture class
+ *
+ * @ingroup Evas_Canvas3D_Texture
+ */
 #define EVAS_CANVAS3D_TEXTURE_CLASS evas_canvas3d_texture_class_get()
 
-EWAPI const Eo_Class *evas_canvas3d_texture_class_get(void);
+EWAPI const Efl_Class *evas_canvas3d_texture_class_get(void);
 
 /**
  * @brief Set the visibility flag of the source evas object of the given
@@ -113,6 +117,8 @@ EOAPI void evas_canvas3d_texture_source_set(Eo *obj, Efl_Canvas_Object *source);
  * See also @ref evas_canvas3d_texture_data_set,
  * @ref evas_canvas3d_texture_file_set, @ref evas_canvas3d_texture_source_set.
  *
+ * @return Color format of the given texture
+ *
  * @ingroup Evas_Canvas3D_Texture
  */
 EOAPI Evas_Colorspace evas_canvas3d_texture_color_format_get(const Eo *obj);
@@ -184,5 +190,4 @@ EOAPI void evas_canvas3d_texture_filter_set(Eo *obj, Evas_Canvas3D_Texture_Filte
  */
 EOAPI void evas_canvas3d_texture_filter_get(const Eo *obj, Evas_Canvas3D_Texture_Filter *min, Evas_Canvas3D_Texture_Filter *mag);
 
-
 #endif
